@@ -45,6 +45,7 @@ static recipe *get_empty_formula() {
   t->index = 0;
   t->transmute = 0;
   t->yield=0;
+  t->keycode = 0;
   t->title = NULL;
   t->arch_name = NULL;
   t->ingred = NULL;
@@ -125,6 +126,9 @@ void init_formulae() {
       formula=get_empty_formula();
       formula->title = add_string(strchr(cp,' ') + 1);
     }
+    else if (!strncmp(cp, "keycode", 7)) {
+      formula->keycode = add_string(strchr(cp,' ') + 1);
+    }
     else if (sscanf(cp, "trans %d", &value)) {
         formula->transmute = (uint16) value;
     }
@@ -563,11 +567,13 @@ recipe * get_random_recipe ( recipelist *rpl ) {
 
   /* looks like we have to choose a random one */ 
   if(fl==NULL) if((fl=get_random_recipelist())==NULL) return rp;
-
-  r=RANDOM()%fl->total_chance;
-  for (rp=fl->items;rp;rp=rp->next) {
+  
+  if (fl->total_chance > 0) {
+    r=RANDOM()%fl->total_chance;
+    for (rp=fl->items;rp;rp=rp->next) {
       r -= rp->chance;
       if (r<0) break;
+    }
   }
   return rp;
 }
