@@ -16,6 +16,9 @@ typedef struct _CrEditRec      *CrEditWidget;
 #define XtNstacking "stacking"
 #define XtCStacking "Stacking"
 
+#define XtNshow_weak_walls "show_weak_walls"
+#define XtCShow_weak_walls "Show_weak_walls"
+
 #define XtNselectArea "selectArea"
 #define XtCSelectArea "SelectArea"
 
