@@ -1,11 +1,12 @@
 /*
  * static char *rcsid_living_h =
- *   "$Id: living.h,v 1.22 1998/09/28 02:48:25 master Exp $";
+ *   "$Id: living.h,v 1.6 2000/05/27 05:23:22 cvs Exp $";
  */
 
 /*
     CrossFire, A Multiplayer game for X-windows
 
+    Copyright (C) 2000 Mark Wedel
     Copyright (C) 1992 Frank Tore Johansen
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    The author can be reached via e-mail to mark@pyramid.com.
+    The author can be reached via e-mail to mwedel@scruz.net
 */
 
 #ifndef LIVING_H
@@ -36,7 +37,10 @@
 #define INT 5
 #define POW 6
 
-#define NO_STAT 99    /* needed by skills code -b.t. */
+/* Changed from NO_STAT to NO_STAT_VAL to fix conlfict on
+ * AIX systems
+ */
+#define NO_STAT_VAL 99    /* needed by skills code -b.t. */
 
 extern char *attacks[NROFATTACKS];
 extern char *spellpathnames[NRSPELLPATHS];
@@ -50,7 +54,6 @@ extern int dam_bonus[MAX_STAT + 1];
 extern int savethrow[111];
 extern int turn_bonus[MAX_STAT + 1];
 extern int learn_prayer_chance[MAX_STAT + 1];
-extern int object_saves[NROFATTACKS][NROFMATERIALS];
 extern int learn_spell[];
 extern char *restore_msg[7];
 extern char *statname[7];
